@@ -80,7 +80,7 @@ def _run_acq_hook(bridge_port, bridge_timeout, pull_port, push_port, hook_connec
         event_msg = pull_socket.receive()
 
         if "special" in event_msg and event_msg["special"] == "acquisition-end":
-            push_socket.send({})
+            push_socket.send(event_msg)
             push_socket.close()
             pull_socket.close()
             return
@@ -88,17 +88,17 @@ def _run_acq_hook(bridge_port, bridge_timeout, pull_port, push_port, hook_connec
             if "events" in event_msg.keys():
                 event_msg = event_msg["events"]  # convert from sequence
             params = signature(hook_fn).parameters
-            if len(params) == 1 or len(params) == 3:
+            if len(params) == 1 or len(params) == 2:
                 try:
                     if len(params) == 1:
                         new_event_msg = hook_fn(event_msg)
-                    elif len(params) == 3:
-                        new_event_msg = hook_fn(event_msg, bridge, event_queue)
+                    elif len(params) == 2:
+                        new_event_msg = hook_fn(event_msg, event_queue)
                 except Exception as e:
                     warnings.warn("exception in acquisition hook: {}".format(e))
                     continue
             else:
-                raise Exception("Incorrect number of arguments for hook function. Must be 1 or 3")
+                raise Exception("Incorrect number of arguments for hook function. Must be 1 or 2")
 
         if isinstance(new_event_msg, list):
             new_event_msg = {
@@ -187,7 +187,7 @@ def _run_image_processor(
 
         if "special" in message and message["special"] == "finished":
             pull_socket.close()
-            push_socket.send(message)  # Continue propagating the finihsed signal
+            push_socket.send(message)  # Continue propagating the finished signal
             push_socket.close()
             return
 
@@ -199,19 +199,19 @@ def _run_image_processor(
             image = np.reshape(pixels, [metadata["Height"], metadata["Width"]])
 
         params = signature(process_fn).parameters
-        if len(params) == 2 or len(params) == 4:
+        if len(params) == 2 or len(params) == 3:
             processed = None
             try:
                 if len(params) == 2:
                     processed = process_fn(image, metadata)
-                elif len(params) == 4:
-                    processed = process_fn(image, metadata, bridge, event_queue)
+                elif len(params) == 3:
+                    processed = process_fn(image, metadata, event_queue)
             except Exception as e:
                 warnings.warn("exception in image processor: {}".format(e))
                 continue
         else:
             raise Exception(
-                "Incorrect number of arguments for image processing function, must be 2 or 4"
+                "Incorrect number of arguments for image processing function, must be 2 or 3"
             )
 
         if processed is None:
@@ -249,6 +249,7 @@ def _storage_monitor_fn(
 
 
 
+
 class Acquisition(object, metaclass=NumpyDocstringInheritanceMeta):
     """
     Base class for Pycro-Manager acquisitions
@@ -284,36 +285,35 @@ class Acquisition(object, metaclass=NumpyDocstringInheritanceMeta):
         image_process_fn : Callable
             image processing function that will be called on each image that gets acquired.
             Can either take two arguments (image, metadata) where image is a numpy array and metadata is a dict
-            containing the corresponding iamge metadata. Or a 4 argument version is accepted, which accepts (image,
-            metadata, bridge, queue), where bridge and queue are an instance of the pycromanager.bridge.Bridge
-            object for the purposes of interacting with arbitrary code on the Java side (such as the micro-manager
-            core), and queue is a Queue objects that holds upcomning acquisition events. Both version must either
-            return
+            containing the corresponding image metadata. Or a 4 argument version is accepted, which accepts (image,
+            metadata, queue), where queue is a Queue object that holds upcoming acquisition events. The function
+            should return either an (image, metadata) tuple or a list of such tuples
         event_generation_hook_fn : Callable
             hook function that will as soon as acquisition events are generated (before hardware sequencing optimization
             in the acquisition engine. This is useful if one wants to modify acquisition events that they didn't generate
             (e.g. those generated by a GUI application). Accepts either one argument (the current acquisition event)
-            or three arguments (current event, bridge, event Queue)
+            or three arguments (current event, event_queue)
         pre_hardware_hook_fn : Callable
             hook function that will be run just before the hardware is updated before acquiring
             a new image. In the case of hardware sequencing, it will be run just before a sequence of instructions are
-            dispatched to the hardware. Accepts either one argument (the current acquisition event) or three arguments
-            (current event, bridge, event Queue)
+            dispatched to the hardware. Accepts either one argument (the current acquisition event) or two arguments
+            (current event, bridge, event_queue)
         post_hardware_hook_fn : Callable
             hook function that will be run just before the hardware is updated before acquiring
             a new image. In the case of hardware sequencing, it will be run just after a sequence of instructions are
             dispatched to the hardware, but before the camera sequence has been started. Accepts either one argument
-            (the current acquisition event) or three arguments (current event, bridge, event Queue)
+            (the current acquisition event) or two arguments (current event, event_queue)
         post_camera_hook_fn : Callable
             hook function that will be run just after the camera has been triggered to snapImage or
             startSequence. A common use case for this hook is when one want to send TTL triggers to the camera from an
             external timing device that synchronizes with other hardware. Accepts either one argument (the current
-            acquisition event) or three arguments (current event, bridge, event Queue)
+            acquisition event) or two arguments (current event, event_queue)
         show_display : bool or str
             If True, show the image viewer window. If False, show no viewer. If 'napari', show napari as the viewer
         image_saved_fn : Callable
             function that takes two arguments (the Axes of the image that just finished saving, and the Dataset)
-            and gets called whenever a new image is written to disk
+            or three arguments (Axes, Dataset and the event_queue) and gets called whenever a new image is written to
+            disk
         process : bool
             Use multiprocessing instead of multithreading for acquisition hooks and image
             processors. This can be used to speed up CPU-bounded processing by eliminating bottlenecks
@@ -357,7 +357,7 @@ class Acquisition(object, metaclass=NumpyDocstringInheritanceMeta):
         self._initialize_image_processor(**named_args)
         self._initialize_hooks(**named_args)
 
-        self._remote_acq.start()
+        # self._remote_acq.start()
         self._dataset_disk_location = (
             self._remote_acq.get_storage().get_disk_location()
             if self._remote_acq.get_storage() is not None
@@ -367,10 +367,17 @@ class Acquisition(object, metaclass=NumpyDocstringInheritanceMeta):
         self._start_events()
 
         # Load remote storage
-        remote_storage_monitor = self._remote_acq.get_storage_monitor()
-        if remote_storage_monitor is not None:
-            self._dataset = Dataset(remote_storage_monitor=remote_storage_monitor)
+        self._remote_storage_monitor = self._remote_acq.get_storage_monitor()
+        if self._remote_storage_monitor is not None:
+            self._dataset = Dataset(remote_storage_monitor=self._remote_storage_monitor)
             if image_saved_fn is not None:
+                params = signature(image_saved_fn).parameters
+                if len(params) == 2:
+                    pass
+                elif len(params) == 3:
+                    callback_fn = lambda axes, dataset: callback_fn(axes, dataset, self._event_queue)
+                else:
+                    raise Exception('Image saved callbacks must have either 2 or three parameters')
                 self._storage_monitor_thread = self._dataset._add_storage_monitor_fn(_storage_monitor_fn,
                     callback_fn=image_saved_fn, debug=self._debug
                 )
@@ -681,7 +688,7 @@ class XYTiledAcquisition(Acquisition):
         """
         self.tile_overlap = tile_overlap
         self.max_multi_res_index = max_multi_res_index
-        # Collct all argument values except the ones specific to Magellan
+        # Collct all argument values except the ones specific to XY Tiled acquisitions
         arg_names = list(signature(self.__init__).parameters.keys())
         arg_names.remove('tile_overlap')
         arg_names.remove('max_multi_res_index')
